@@ -2381,7 +2381,7 @@ int juman_sent(void)
     int        pos_end, length;
     int        pre_m_buffer_num;
     int        pre_p_buffer_num;
-    int        pos, next_pos = 0, deleted_num;
+    int        pos, next_pos = 0, deleted_num, local_deleted_num;
     int	       p_start = 0;
 
     if (mrph_buffer_max == 0) {
@@ -2421,6 +2421,7 @@ int juman_sent(void)
     if (LongSoundRep_Opt || LowercaseRep_Opt) strcpy(NormalizedString, String); /* 非正規表記への対応 */
     if (LongSoundDel_Opt || LowercaseDel_Opt) {
 	deleted_num = 0;
+	local_deleted_num = 0;
 	for (pos = 0; pos < length; pos++) String2PDS[pos] = -2;
     }
     for (pos = 0; pos < length; pos+=next_pos) {
@@ -2462,7 +2463,7 @@ int juman_sent(void)
 	if ((LongSoundDel_Opt || LowercaseDel_Opt) && next_pos == BYTES4CHAR) {
 	    pre_code = (BYTES4CHAR <= pos) ? check_code(String, pos - BYTES4CHAR) : -1;
 	    post_code = check_code(String, pos + BYTES4CHAR); /* 文末の場合は0 */
-	    if (LongSoundDel_Opt && pre_code > 0 &&
+	    if (LongSoundDel_Opt && pre_code > 0 && (WORD_CHAR_NUM_MAX + local_deleted_num + 1) * BYTES4CHAR < MIDASI_MAX &&
 		/* 直前が削除された長音記号、平仮名、または、漢字かつ直後が平仮名 */
 		((String2PDS[pos - BYTES4CHAR] == -1 ||
 		  pre_code == HIRAGANA || pre_code == KANJI && post_code == HIRAGANA) &&
@@ -2473,9 +2474,10 @@ int juman_sent(void)
 		(String2PDS[pos - BYTES4CHAR] == -1 && !strncmp(String + pos, DEF_PROLONG_SYMBOL3, BYTES4CHAR) &&
 		 (post_code == 0 || post_code == KIGOU))) {
 		deleted_num++;
+		local_deleted_num++;
 		String2PDS[pos] = -1;
 	    }
-	    else if (LowercaseDel_Opt && pre_code > 0) {
+	    else if (LowercaseDel_Opt && pre_code > 0 && (WORD_CHAR_NUM_MAX + local_deleted_num + 1) * BYTES4CHAR < MIDASI_MAX) {
 		/* 小書き文字による長音化 */
 		for (i = DELETE_LOWERCASE_S; i < DELETE_LOWERCASE_E; i++) {
 		    if (!strncmp(String + pos, lowercase[i], BYTES4CHAR)) {
@@ -2486,12 +2488,16 @@ int juman_sent(void)
 			if (j < pre_lower_end[i] ||
 			    String2PDS[pos - BYTES4CHAR] == -1 && !strncmp(String + pos - BYTES4CHAR, String + pos, BYTES4CHAR)) {
 			    deleted_num++;
+			    local_deleted_num++;
 			    String2PDS[pos] = -1;
 			    break;
 			}
 		    }
 		}
 	    }
+	    else {
+		local_deleted_num = 0;
+	    }
 
 	    if (String2PDS[pos] != -1) {
 		for (i = 0; i < next_pos; i++) ProlongDeletedString[pos - deleted_num * BYTES4CHAR + i] = String[pos + i];
